summaryrefslogtreecommitdiffstats
path: root/src/yuzu_cmd/emu_window/emu_window_sdl2.h
diff options
context:
space:
mode:
authorcomex <comexk@gmail.com>2020-11-22 22:05:18 +0100
committercomex <comexk@gmail.com>2020-11-23 23:58:49 +0100
commit994f4977810749c0b597e7a7531a02d907967a68 (patch)
tree82eaf8b6dea5baf60e17601771dc8191b8e69a8f /src/yuzu_cmd/emu_window/emu_window_sdl2.h
parentMerge pull request #4451 from slashiee/extended-logging (diff)
downloadyuzu-994f4977810749c0b597e7a7531a02d907967a68.tar
yuzu-994f4977810749c0b597e7a7531a02d907967a68.tar.gz
yuzu-994f4977810749c0b597e7a7531a02d907967a68.tar.bz2
yuzu-994f4977810749c0b597e7a7531a02d907967a68.tar.lz
yuzu-994f4977810749c0b597e7a7531a02d907967a68.tar.xz
yuzu-994f4977810749c0b597e7a7531a02d907967a68.tar.zst
yuzu-994f4977810749c0b597e7a7531a02d907967a68.zip
Diffstat (limited to 'src/yuzu_cmd/emu_window/emu_window_sdl2.h')
-rw-r--r--src/yuzu_cmd/emu_window/emu_window_sdl2.h20
1 files changed, 10 insertions, 10 deletions
diff --git a/src/yuzu_cmd/emu_window/emu_window_sdl2.h b/src/yuzu_cmd/emu_window/emu_window_sdl2.h
index 53d756c3c..a93141240 100644
--- a/src/yuzu_cmd/emu_window/emu_window_sdl2.h
+++ b/src/yuzu_cmd/emu_window/emu_window_sdl2.h
@@ -23,38 +23,38 @@ public:
explicit EmuWindow_SDL2(InputCommon::InputSubsystem* input_subsystem);
~EmuWindow_SDL2();
- /// Polls window events
- void PollEvents() override;
-
/// Whether the window is still open, and a close request hasn't yet been sent
bool IsOpen() const;
/// Returns if window is shown (not minimized)
bool IsShown() const override;
+ /// Wait for the next event on the main thread.
+ void WaitEvent();
+
protected:
/// Called by PollEvents when a key is pressed or released.
void OnKeyEvent(int key, u8 state);
/// Called by PollEvents when the mouse moves.
void OnMouseMotion(s32 x, s32 y);
/// Called by PollEvents when a mouse button is pressed or released
void OnMouseButton(u32 button, u8 state, s32 x, s32 y);
/// Translates pixel position (0..1) to pixel positions
std::pair<unsigned, unsigned> TouchToPixelPos(float touch_x, float touch_y) const;
/// Called by PollEvents when a finger starts touching the touchscreen
void OnFingerDown(float x, float y);
/// Called by PollEvents when a finger moves while touching the touchscreen
void OnFingerMotion(float x, float y);
/// Called by PollEvents when a finger stops touching the touchscreen
void OnFingerUp();
/// Called by PollEvents when any event that may cause the window to be resized occurs
void OnResize();
/// Called when user passes the fullscreen parameter flag
@@ -23,38 +23,38 @@ public:
protected:
- /// Called by PollEvents when a key is pressed or released.
+ /// Called by WaitEvent when a key is pressed or released.
void OnKeyEvent(int key, u8 state);
@@ -23,38 +23,38 @@ public:
void OnKeyEvent(int key, u8 state);
- /// Called by PollEvents when the mouse moves.
+ /// Called by WaitEvent when the mouse moves.
void OnMouseMotion(s32 x, s32 y);
@@ -23,38 +23,38 @@ public:
void OnMouseMotion(s32 x, s32 y);
- /// Called by PollEvents when a mouse button is pressed or released
+ /// Called by WaitEvent when a mouse button is pressed or released
void OnMouseButton(u32 button, u8 state, s32 x, s32 y);
/// Translates pixel position (0..1) to pixel positions
@@ -23,38 +23,38 @@ public:
/// Translates pixel position (0..1) to pixel positions
std::pair<unsigned, unsigned> TouchToPixelPos(float touch_x, float touch_y) const;
- /// Called by PollEvents when a finger starts touching the touchscreen
+ /// Called by WaitEvent when a finger starts touching the touchscreen
void OnFingerDown(float x, float y);
@@ -23,38 +23,38 @@ public:
void OnFingerDown(float x, float y);
- /// Called by PollEvents when a finger moves while touching the touchscreen
+ /// Called by WaitEvent when a finger moves while touching the touchscreen
void OnFingerMotion(float x, float y);
@@ -23,38 +23,38 @@ public:
void OnFingerMotion(float x, float y);
- /// Called by PollEvents when a finger stops touching the touchscreen
+ /// Called by WaitEvent when a finger stops touching the touchscreen
void OnFingerUp();
@@ -23,38 +23,38 @@ public:
void OnFingerUp();
- /// Called by PollEvents when any event that may cause the window to be resized occurs
+ /// Called by WaitEvent when any event that may cause the window to be resized occurs
void OnResize();
/// Called when user passes the fullscreen parameter flag